package com.docus.server.message.mapper;


import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.Date;
import java.util.List;

@Mapper
public interface TBasicMapper {
    List<String> getPatientIdsByInpatientNoAndTimes(@Param("inpatientNo") String inHospIndexNo, @Param("admissTimes") Integer visitNo);

    /**
     * 更新医生提交时间
     *
     * @param patientId  病案主键
     * @param submitTime 提交时间
     * @return database操作行
     */
    int insertOrUpdateDoctorSubmitTime(@Param("patientId") String patientId, @Param("submitTime") Date submitTime);

    /**
     * 更新护士提交时间
     *
     * @param patientId  病案主键
     * @param submitTime 提交时间
     * @return database操作行
     */
    int insertOrUpdateNurseSubmitTime(@Param("patientId") String patientId, @Param("submitTime") Date submitTime);

    /**
     * 更新护理文件数量
     *
     * @param patientId 病案主键
     * @param fileCount 文件数量
     * @return database操作行
     */
    int insertOrUpdateNurseFileCount(@Param("patientId") String patientId, @Param("fileCount") Integer fileCount);


    /**
     * 更新质控护士和责任护士
     *
     * @param patientId 病案主键
     * @param qcNurse 质控护士
     * @param dutyNurse 责任护士
     * @return database操作行
     */
    int insertOrUpdateNurse(@Param("patientId") String patientId, @Param("qcNurse") String qcNurse, @Param("dutyNurse") String dutyNurse);

    /**
     * 根据病案主键查询出院病案的数量，一般用于判断病案是否出院
     *
     * @param patientId 病案主键
     * @return 出院数量
     */
    int getDischargeCount(@Param("patientId") String patientId);

    /**
     * 更新出院时间
     *
     * @param patientId 病案主键
     * @param disDate   出院时间
     * @return database操作行
     */
    int updateDisDateTime(@Param("patientId") String patientId, @Param("disDate") String disDate);

    /**
     * 更新基础信息，是否重症患者
     *
     * @param inpatientNo 病案号
     * @param admissTimes 住院次数
     * @param state       状态 1是，0否
     * @return 数据库操作行
     */
    int updIcuRecordState(@Param("inpatientNo") String inpatientNo, @Param("admissTimes") Integer admissTimes, @Param("state") int state);

    /**
     * 根据病案主键和来源，统计未作废的文件数量
     *
     * @param patientId 病案主键
     * @param source    系统/采集来源
     * @return 未作废文件数量
     */
    int getFileCountByPatientAndSource(@Param("patientId") String patientId, @Param("source") String source);

    /**
     * 更新电子病历提交状态
     *
     * @param patientId      病案主键
     * @param emrSubmitState 提交状态 0 否 1 是
     * @return 数据库操作
     */
    int updateEmrSubmitState(@Param("patientId") String patientId, @Param("emrSubmitState") int emrSubmitState);

}
